#[repr(transparent)]pub struct Cfg(pub u32);Expand description
Configuration register
Tuple Fields
0: u32Implementations
Sourceimpl Cfg
impl Cfg
Sourcepub const fn set_adiclk(&mut self, val: Adiclk)
pub const fn set_adiclk(&mut self, val: Adiclk)
Input Clock Select
Sourcepub const fn set_adlsmp(&mut self, val: Adlsmp)
pub const fn set_adlsmp(&mut self, val: Adlsmp)
Long Sample Time Configuration
Sourcepub const fn adsts(&self) -> Adsts
pub const fn adsts(&self) -> Adsts
Defines the total sample time duration in number of full cycles
Sourcepub const fn set_adsts(&mut self, val: Adsts)
pub const fn set_adsts(&mut self, val: Adsts)
Defines the total sample time duration in number of full cycles
Sourcepub const fn set_refsel(&mut self, val: Refsel)
pub const fn set_refsel(&mut self, val: Refsel)
Voltage Reference Selection
Sourcepub const fn set_ovwren(&mut self, val: Ovwren)
pub const fn set_ovwren(&mut self, val: Ovwren)
Data Overwrite Enable